@@ -230,3 +230,34 @@ get_regime_means <- function(gmvar) {
 }
 
 
+#' @title Calculate absolute values of the eigenvalues of the "bold A" matrices containing the AR coefficients
+#'
+#' @description \code{get_boldA_eigens} calculates absolute values of the eigenvalues of
+#'   the "bold A" matrices containing the AR coefficients for each mixture component
+#'
+#' @inheritParams simulateGMVAR
+#' @return Returns a list with \eqn{M} elements - one for each regime. Each element contains
+#'  the absolute values (or modulus) of the eigenvalues of the "bold A" matrix containing
+#'  the AR coefficients.
+#' @inherit is_stationary references
+#' @examples
+#' params222 <- c(-11.904, 154.684, 1.314, 0.145, 0.094, 1.292, -0.389,
+#'  -0.070, -0.109, -0.281, 0.920, -0.025, 4.839, 11.633, 124.983, 1.248,
+#'   0.077, -0.040, 1.266, -0.272, -0.074, 0.034, -0.313, 5.855, 3.570,
+#'   9.838, 0.740)
+#' mod222 <- GMVAR(d=2, p=2, M=2, params=params222, parametrization="mean")
+#' get_boldA_eigens(mod222)
+#' @export
+
+get_boldA_eigens <- function(gmvar) {
+  check_gmvar(gmvar)
+  p <- gmvar$model$p
+  M <- gmvar$model$M
+  d <- gmvar$model$d
+  params <- reform_constrained_pars(p=p, M=M, d=d, params=gmvar$params, constraints=gmvar$model$constraints)
+  all_A <- pick_allA(p=p, M=M, d=d, params=params)
+  all_boldA <- form_boldA(p=p, M=M, d=d, all_A=all_A)
+  lapply(1:M, function(m) abs(eigen(all_boldA[, , m], symmetric=FALSE, only.values=TRUE)$'values'))
+}
+
+
